<?php
namespace Fifa\ConnectServiceBus\Sdk\Environment;

use Fifa\ConnectServiceBus\Sdk\Authentication\AuthenticationResourceBuilderInterface;
use Fifa\ConnectServiceBus\Sdk\Authentication\ConnectServiceBusAuthenticationResourceBuilder;

/**
 * Class EnvironmentSettings
 * @package Fifa\ConnectServiceBus\Sdk\Environment
 */
class EnvironmentSettings
{
    /**
     * @var AuthenticationResourceBuilderInterface
     */
    private $authenticationResourceBuilder;

    /**
     * @var null|string
     */
    private $cacheFolder;

    /**
     * EnvironmentSettings constructor.
     * @param AuthenticationResourceBuilderInterface|null $authenticationResourceBuilder
     * @param string|null $cacheFolder
     */
    public function __construct($cacheFolder = null, AuthenticationResourceBuilderInterface $authenticationResourceBuilder = null)
    {
        if (is_null($authenticationResourceBuilder)) {
            $authenticationResourceBuilder = new ConnectServiceBusAuthenticationResourceBuilder();
        }

        $this->authenticationResourceBuilder = $authenticationResourceBuilder;
        $this->cacheFolder = $cacheFolder;
    }

    /**
     * @return AuthenticationResourceBuilderInterface
     */
    public function getAuthenticationResourceBuilder()
    {
        return $this->authenticationResourceBuilder;
    }

    /**
     * @return null|string
     */
    public function getCacheFolder()
    {
        return $this->cacheFolder;
    }
}