<?php
namespace Fifa\ConnectServiceBus\Sdk\Utils;

/**
 * Class FileCache
 * @package Fifa\ConnectServiceBus\Sdk\Utils
 */
class FileCache
{
    /**
     * @var int
     */
    private $validLimit;

    /**
     * @var string
     */
    private $filePath;

    /**
     * FileCache constructor.
     * @param string|null $folderPath
     */
    public function __construct($folderPath = null)
    {
        $defaultCacheFolder = str_replace('src' . DIRECTORY_SEPARATOR . 'Utils', '', dirname(__FILE__)) . '.cache' . DIRECTORY_SEPARATOR;
        $this->setFilePath(is_string($folderPath) ? $folderPath : $defaultCacheFolder);
    }

    /**
     * Returns string representation of the object
     *
     * @return string
     */
    public function __toString()
    {
        return "FilePath: " . $this->getFilePath() . ', ValidLimit: ' . $this->getValidLimit();
    }

    /**
     * Sets validity limit
     *
     * @param int $validLimit
     * @return FileCache
     */
    public function setValidLimit($validLimit)
    {
        $this->validLimit = $validLimit;
        return $this;
    }

    /**
     * Gets validity limit
     *
     * @return int
     */
    public function getValidLimit()
    {
        return $this->validLimit;
    }

    /**
     * Sets file path
     *
     * @param string $filePath
     * @return FileCache
     *
     * @throws \InvalidArgumentException
     * @throws \RuntimeException
     */
    public function setFilePath($filePath)
    {
        if (!file_exists($filePath)) {
            throw new \InvalidArgumentException('Given folder location doesn\'t exist: "' . $filePath . '".');
        }

        if (!is_writable($filePath)) {
            throw new \RuntimeException('Folder "' . $filePath . '" is not writable."');
        }

        $this->filePath = $filePath;
        return $this;
    }

    /**
     * Gets file path
     *
     * @return string
     */
    public function getFilePath()
    {
        return $this->filePath;
    }

    /**
     * Gets data from cache file. Returns null in case when file doesn't exist;
     *
     * @param string $filenameKey
     * @return mixed|null
     */
    protected function getFromCache($filenameKey)
    {
        $data = null;
        if (file_exists($this->filePath . $this->generateFilename($filenameKey))){
            $data = unserialize(File::getContents($this->filePath . $this->generateFilename($filenameKey)));
        }

        return $data;
    }

    /**
     * Store given object into cache
     *
     * @param string $filenameKey
     * @param mixed $object
     */
    protected function putIntoCache($object, $filenameKey)
    {
        file_put_contents($this->filePath . $this->generateFilename($filenameKey), serialize($object));
    }

    /**
     * Generates and returns cache file name
     *
     * @param string $input
     * @return string
     */
    protected function generateFilename($input)
    {
        return md5(serialize($input)) . '.cache';
    }
}